quscope.image\_processing.quantum\_encoding
===========================================

.. automodule:: quscope.image_processing.quantum_encoding

   
   .. rubric:: Functions

   .. autosummary::
   
      analyze_encoding_resources
      calculate_required_qubits
      encode_binary_image
      encode_image_to_circuit
      encode_multichannel_image
      get_encoding_probabilities
      get_encoding_statevector
      validate_image_array
   
   .. rubric:: Classes

   .. autosummary::
   
      EncodingMethod
   
   .. rubric:: Exceptions

   .. autosummary::
   
      EncodingDimensionError
      EncodingError
      InvalidImageError
   